## $Id: viewlets.py 9439 2012-10-27 06:18:08Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from waeup.kofa.interfaces import REQUESTED
from waeup.kofa.browser.viewlets import ManageActionButton
from waeup.uniben.students.interfaces import ICustomStudentStudyCourse
from waeup.kofa.students.viewlets import (
    FileDisplay, FileUpload, Image)
from waeup.kofa.students.browser import (
    ExportPDFClearanceSlipPage, StudyCourseDisplayFormPage)

from kofacustom.nigeria.interfaces import MessageFactory as _

class StudyCourseEditActionButton(ManageActionButton):
    grok.order(1)
    grok.context(ICustomStudentStudyCourse)
    grok.view(StudyCourseDisplayFormPage)
    grok.require('waeup.clearStudent')
    text = _('Edit level')
    target = 'edit_level'

    @property
    def target_url(self):
        if self.context.is_current and self.context.student.state == REQUESTED:
            return self.view.url(self.view.context, self.target)
        return False

# JAMB Letter

class JAMBLetterDisplay(FileDisplay):
    """JAMB Letter display viewlet.
    """
    grok.order(19)
    label = _(u'JAMB Letter')
    title = _(u'JAMB Letter')
    download_name = u'cert'

class JAMBLetterSlip(JAMBLetterDisplay):
    grok.view(ExportPDFClearanceSlipPage)

class JAMBLetterUpload(FileUpload):
    """JAMB Letter upload viewlet.
    """
    grok.order(19)
    label = _(u'JAMB Letter')
    title = _(u'JAMB Letter Scan')
    mus = 1024 * 150
    download_name = u'cert'

class JAMBLetterImage(Image):
    """Renders JAMB Letter scan.
    """
    grok.name('cert')
    download_name = u'cert'

# Affidavit of Non-Membership of Secret Cults

class SecrCultsStatementDisplay(FileDisplay):
    """Affidavit of Non-Membership of Secret Cults display viewlet.
    """
    grok.order(20)
    label = _(u'Affidavit of Non-Membership of Secret Cults')
    title = _(u'Affidavit of Non-Membership of Secret Cults')
    download_name = u'secr_cults'

class SecrCultsStatementSlip(SecrCultsStatementDisplay):
    grok.view(ExportPDFClearanceSlipPage)

class SecrCultsStatementUpload(FileUpload):
    """Affidavit of Non-Membership of Secret Cults upload viewlet.
    """
    grok.order(20)
    label = _(u'Affidavit of Non-Membership of Secret Cults')
    title = _(u'Affidavit of Non-Membership of Secret Cults Scan')
    mus = 1024 * 150
    download_name = u'secr_cults'

class ResultStatementImage(Image):
    """Renders Affidavit of Non-Membership of Secret Cults scan.
    """
    grok.name('secr_cults')
    download_name = u'secr_cults'